import { getInputDir, getOutputDir, makeDirSync } from "./env";
const fs = require("fs");
const path = require("path");

/**
 * 旋转图片，并保存为正式文件
 * @param {*} scaningImageList 图片路径
 * @param {String} paperInfo 保持文件名称
 */
export function saveOutputImage(scaningImageList, paperInfo) {
  let outputOriginPaths = [];
  for (let i = 0; i < scaningImageList.length; i++) {
    const imagePath = scaningImageList[i];
    const originImageFile = saveOriginImage(imagePath, paperInfo);
    outputOriginPaths.push(originImageFile);
    fs.unlinkSync(imagePath);
  }

  return outputOriginPaths;
}

function saveOriginImage(imagePath, paperInfo) {
  const outputDir = path.join(getOutputDir("origin"), paperInfo.taskId + "");

  if (!fs.existsSync(outputDir)) makeDirSync(outputDir);
  const outputOriginPath = path.join(outputDir, path.basename(imagePath));
  fs.copyFileSync(imagePath, outputOriginPath);
  return outputOriginPath;
}

/**
 * 获取最早添加的文件
 * @param {String} dir 图片目录
 */
export function getEarliestFile(dir) {
  const ddir = dir || getInputDir();
  const files = fs
    .readdirSync(ddir)
    .filter(fileName => fileName.toLowerCase().match(/\.(jpg|png|jpeg)/))
    .map(fileName => {
      return {
        name: fileName,
        time: fs.statSync(path.join(ddir, fileName)).birthtimeMs
      };
    })
    .sort((a, b) => a.time - b.time);

  if (!files.length) return { url: "", name: "" };

  return {
    url: path.join(ddir, files[0].name),
    name: files[0].name
  };
}
